pub struct NarrowPhasePlugin<C: AnyCollider, H: CollisionHooks = ()> { /* private fields */ }Expand description
A narrow phase plugin for updating and managing contact pairs
between colliders of type C.
See the module-level documentation for more information.
Collider Types
The plugin takes a collider type. This should be Collider for
the vast majority of applications, but for custom collision backends
you may use any collider that implements the AnyCollider trait.
Implementations
Sourceimpl<C: AnyCollider, H: CollisionHooks> NarrowPhasePlugin<C, H>
impl<C: AnyCollider, H: CollisionHooks> NarrowPhasePlugin<C, H>
Sourcepub fn new(schedule: impl ScheduleLabel, generate_constraints: bool) -> Self
pub fn new(schedule: impl ScheduleLabel, generate_constraints: bool) -> Self
Creates a NarrowPhasePlugin with the schedule used for running its systems
and whether it should generate ContactConstraints for the ContactConstraints resource.
Contact constraints are used by the SolverPlugin for solving contacts.
The default schedule is PhysicsSchedule.